@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -154,10 +154,10 @@ MagickExport MagickBooleanType CloneImageProfiles(Image *image,
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(clone_image != (const Image *) NULL);
   assert(clone_image->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (clone_image->profiles != (void *) NULL)
     {
       if (image->profiles != (void *) NULL)
@@ -196,7 +196,7 @@ MagickExport MagickBooleanType DeleteImageProfile(Image *image,const char *name)
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->profiles == (SplayTreeInfo *) NULL)
     return(MagickFalse);
@@ -264,7 +264,7 @@ MagickExport const StringInfo *GetImageProfile(const Image *image,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->profiles == (SplayTreeInfo *) NULL)
     return((StringInfo *) NULL);
@@ -299,7 +299,7 @@ MagickExport char *GetNextImageProfile(const Image *image)
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->profiles == (SplayTreeInfo *) NULL)
     return((char *) NULL);
@@ -399,7 +399,7 @@ static void cmsDeleteContext(cmsContext magick_unused(ContextID))
 }
 #endif
 
-static void **DestroyPixelThreadSet(void **pixels)
+static void **DestroyPixelTLS(void **pixels)
 {
   ssize_t
     i;
@@ -413,7 +413,7 @@ static void **DestroyPixelThreadSet(void **pixels)
   return(pixels);
 }
 
-static void **AcquirePixelThreadSet(const size_t columns,const size_t channels,
+static void **AcquirePixelTLS(const size_t columns,const size_t channels,
   MagickBooleanType highres)
 {
   ssize_t
@@ -440,12 +440,12 @@ static void **AcquirePixelThreadSet(const size_t columns,const size_t channels,
   {
     pixels[i]=AcquireQuantumMemory(columns,channels*size);
     if (pixels[i] == (void *) NULL)
-      return(DestroyPixelThreadSet(pixels));
+      return(DestroyPixelTLS(pixels));
   }
   return(pixels);
 }
 
-static cmsHTRANSFORM *DestroyTransformThreadSet(cmsHTRANSFORM *transform)
+static cmsHTRANSFORM *DestroyTransformTLS(cmsHTRANSFORM *transform)
 {
   ssize_t
     i;
@@ -458,7 +458,7 @@ static cmsHTRANSFORM *DestroyTransformThreadSet(cmsHTRANSFORM *transform)
   return(transform);
 }
 
-static cmsHTRANSFORM *AcquireTransformThreadSet(const LCMSInfo *source_info,
+static cmsHTRANSFORM *AcquireTransformTLS(const LCMSInfo *source_info,
   const LCMSInfo *target_info,const cmsUInt32Number flags,
   cmsContext cms_context)
 {
@@ -483,7 +483,7 @@ static cmsHTRANSFORM *AcquireTransformThreadSet(const LCMSInfo *source_info,
       source_info->type,target_info->profile,target_info->type,
       target_info->intent,flags);
     if (transform[i] == (cmsHTRANSFORM) NULL)
-      return(DestroyTransformThreadSet(transform));
+      return(DestroyTransformTLS(transform));
   }
   return(transform);
 }
@@ -958,9 +958,9 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(name != (const char *) NULL);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if ((datum == (const void *) NULL) || (length == 0))
     {
       char
@@ -1093,7 +1093,6 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
                     "ColorspaceColorProfileMismatch",name);
               }
             highres=MagickTrue;
-#if !defined(MAGICKCORE_HDRI_SUPPORT) || (MAGICKCORE_QUANTUM_DEPTH > 16)
             {
               const char
                 *artifact;
@@ -1102,7 +1101,6 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
               if (IsStringFalse(artifact) != MagickFalse)
                 highres=MagickFalse;
             }
-#endif
             SetLCMSInfoScale(&source_info,1.0);
             SetLCMSInfoTranslate(&source_info,0.0);
             source_info.colorspace=sRGBColorspace;
@@ -1322,7 +1320,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             if (image->black_point_compensation != MagickFalse)
               flags|=cmsFLAGS_BLACKPOINTCOMPENSATION;
 #endif
-            transform=AcquireTransformThreadSet(&source_info,&target_info,flags,
+            transform=AcquireTransformTLS(&source_info,&target_info,flags,
               cms_context);
             if (transform == (cmsHTRANSFORM *) NULL)
               ThrowProfileException(ImageError,"UnableToCreateColorTransform",
@@ -1330,24 +1328,24 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             /*
               Transform image as dictated by the source & target image profiles.
             */
-            source_info.pixels=AcquirePixelThreadSet(image->columns,
+            source_info.pixels=AcquirePixelTLS(image->columns,
               source_info.channels,highres);
-            target_info.pixels=AcquirePixelThreadSet(image->columns,
+            target_info.pixels=AcquirePixelTLS(image->columns,
               target_info.channels,highres);
             if ((source_info.pixels == (void **) NULL) ||
                 (target_info.pixels == (void **) NULL))
               {
-                target_info.pixels=DestroyPixelThreadSet(target_info.pixels);
-                source_info.pixels=DestroyPixelThreadSet(source_info.pixels);
-                transform=DestroyTransformThreadSet(transform);
+                target_info.pixels=DestroyPixelTLS(target_info.pixels);
+                source_info.pixels=DestroyPixelTLS(source_info.pixels);
+                transform=DestroyTransformTLS(transform);
                 ThrowProfileException(ResourceLimitError,
                   "MemoryAllocationFailed",image->filename);
               }
             if (SetImageStorageClass(image,DirectClass,exception) == MagickFalse)
               {
-                target_info.pixels=DestroyPixelThreadSet(target_info.pixels);
-                source_info.pixels=DestroyPixelThreadSet(source_info.pixels);
-                transform=DestroyTransformThreadSet(transform);
+                target_info.pixels=DestroyPixelTLS(target_info.pixels);
+                source_info.pixels=DestroyPixelTLS(source_info.pixels);
+                transform=DestroyTransformTLS(transform);
                 if (source_info.profile != (cmsHPROFILE) NULL)
                   (void) cmsCloseProfile(source_info.profile);
                 if (target_info.profile != (cmsHPROFILE) NULL)
@@ -1431,9 +1429,9 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
               default:
                 break;
             }
-            target_info.pixels=DestroyPixelThreadSet(target_info.pixels);
-            source_info.pixels=DestroyPixelThreadSet(source_info.pixels);
-            transform=DestroyTransformThreadSet(transform);
+            target_info.pixels=DestroyPixelTLS(target_info.pixels);
+            source_info.pixels=DestroyPixelTLS(source_info.pixels);
+            transform=DestroyTransformTLS(transform);
             if ((status != MagickFalse) &&
                 (cmsGetDeviceClass(source_info.profile) != cmsSigLinkClass))
               status=SetImageProfile(image,name,profile,exception);
@@ -1481,7 +1479,7 @@ MagickExport StringInfo *RemoveImageProfile(Image *image,const char *name)
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->profiles == (SplayTreeInfo *) NULL)
     return((StringInfo *) NULL);
@@ -1519,7 +1517,7 @@ MagickExport void ResetImageProfileIterator(const Image *image)
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->profiles == (SplayTreeInfo *) NULL)
     return;
@@ -1963,7 +1961,7 @@ static MagickBooleanType SetImageProfileInternal(Image *image,const char *name,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   clone_profile=CloneStringInfo(profile);
   PatchCorruptProfile(name,clone_profile);
